@@ -44,6 +44,10 @@ def main():
                         "--task",
                         help="task to do, csv, tfrecords, or all",
                         type=str, default=None)
+    parser.add_argument("-s",
+                        "--savetf",
+                        help="save folder for tfrecords",
+                        type=str, default=None)
 
     args = parser.parse_args()
     obj_data(args)
